Source
======

TODO

* General description
* File action (compilation)
* Automatic source detection

Dependencies
------------

TODO

Configuration files
-------------------

TODO

Ignore files
------------

TODO

READMEs
-------

TODO
